===========================
Django Google Drive Storage
===========================

|build-status| |pypi| |docs|

This is a `Django Storage <https://docs.djangoproject.com/en/1.7/ref/files/storage/>`_ implementation that uses `Google Drive <https://drive.google.com>`_ as backend for storing data.

Documentation and Installation instructions
-------------------------------------------

Documentation and installation instructions can be found at `Read The Docs <http://django-googledrive-storage.readthedocs.org/>`_.

.. |build-status| image:: https://travis-ci.org/torre76/django-googledrive-storage.svg?branch=master
    :target: https://travis-ci.org/torre76/django-googledrive-storage
    :alt: Travis CI status

.. |pypi| image:: https://img.shields.io/pypi/v/django-googledrive-storage.svg
    :target: https://pypi.python.org/pypi/django-googledrive-storage/
    :alt: django-googledrive-storage on Pypi

.. |docs| image:: https://readthedocs.org/projects/django-googledrive-storage/badge/?version=latest
    :target: http://django-googledrive-storage.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status
